@@ -1,3 +1,7 @@
+/********************************
+FILE: toc.h
+********************************/
+
 #ifndef __TOC_H_INC
 #define __TOC_H_INC
 
@@ -23,4 +27,4 @@ typedef struct
 #pragma pack()
 
 
-#endif
\ No newline at end of file
+#endif
